<?php
/*
Plugin Name: WP TimeZone
Plugin URI: http://wordpress.org/plugins/wp-timezone/
Description: Automatically changes the WordPress timezone settings based on CET and CEST
Version: 1.0
Author: Ezra Verheijen
Author URI: http://www.qualityinternetsolutions.nl/

	Copyright (C) 2013  Ezra Verheijen @ QIS (info@qualityinternetsolutions.nl)

    This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 3, or 
	any later version, as published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, visit <http://www.gnu.org/licenses/>.
*/

/* 	This plugin can be used if WP's automatic daylight saving and
	scheduled posts are not working properly due to whatever reason.
	
	If this plugin needs to be installed on a multisite, it can also be
	placed in 'mu-plugins' (http://codex.wordpress.org/Must_Use_Plugins).
*/

/**
 * Set UTC offset based on CET/CEST
 *
 * Runs after WordPress has finished loading
 * but before any headers are sent.
 */
add_action( 'init', function() {

	global $wpdb;
		
	/* WordPress default sets to UTC timezone in wp-settings.php */
		
	if ( function_exists( 'date_default_timezone_set' ) )
		date_default_timezone_set( 'Europe/Amsterdam' ); // Choose one, it's all the same

	$timezone = date( 'T' );

	/* Now we have the local timezone stored in $timezone,
	so lets restore WordPress setting as in wp-settings.php */

	if ( function_exists( 'date_default_timezone_set' ) )
		date_default_timezone_set( 'UTC' );
	
	/** Get current offset */
	$current_offset = get_option( 'gmt_offset' );
	
	if ( 'CEST' == $timezone ) // Central European Summer Time
		$offset = '2';
	elseif ( 'CET' == $timezone ) // Central European Time
		$offset = '1';
	
	// Update offset in database if new offset is different
	if ( $offset != $current_offset )
		update_option( 'gmt_offset', $offset );
	
	/**
	 * Set the default timezone to show/handle on admin config page
	 * to avoid confusion and avoid user interference.
	 * Leave empty so WordPress can automatically
	 * fill in the offset being used.
	 */
	$timezone_string = '';
	
	/** Check if a user messed with the settings */
	$current_string = get_option( 'timezone_string' );
	
	// If so, set back to default
	if ( $timezone_string != $current_string )
		update_option( 'timezone_string', $timezone_string );

} );

/**
 * Change the Settings->General Screen to be more clever
 *
 * Note: I wish there was a nicer way to do this,
 * but the admin pages lack the proper hooks for it.
 * Until it gets them, this works.
 */
add_action( 'admin_head', function() {

	global $pagenow;
	
	// Check to see if we're loading the options-general page
	if ( 'options-general.php' != $pagenow )
		return;

	// All looks good, turn on the output buffer and attach our callback
	ob_start( 'wpt_general_callback' );

} );

/**
 * Put a better comment on the Settings->General page
 *
 * @param string $data - The output buffer holding the page data
 */
function wpt_general_callback( $data ) {
	
	/** Convert all applicable characters to HTML entities */
	$converted = htmlentities( $data, ENT_QUOTES, 'UTF-8' );
	
	$replace = array(
		'Kies een plaats in dezelfde tijdzone als waarin je zit.', // Dutch
		'Choose a city in the same timezone as you.', // English
		'W&auml;hle eine Stadt, die in deiner Zeitzone liegt.' // German
	);
	$with = array(
		'Tijdzones worden autmatisch beheerd door de WP TimeZone plugin.', // Dutch
		'Timezones are automatically managed by the WP TimeZone plugin.', // English
		'Zeitzonen werden automatisch verwaltet bei der WP TimeZone Plugin.' // German
	);
	
	$new_string = str_replace( $replace, $with, $converted );
	 
	/** Convert all HTML entities back to their applicable characters */
	$final = html_entity_decode( $new_string, ENT_QUOTES, 'UTF-8' );
	
	return $final;
	
}

// Clean (erase) output buffer and turn off output buffering
ob_end_clean();
